# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with tests
%bcond_with gcj_support

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define section free

Name:           checkstyle
Version:        5.0
Release:        1%{?dist}
Epoch:          0
Summary:        Java source code checker
License:        LGPLv2+
Group:          Development/Build Tools
URL:            http://checkstyle.sourceforge.net/
Source0:        http://download.sf.net/checkstyle/checkstyle-src-5.0.tar.gz
Source1:        checkstyle-5.0-script
Source2:        checkstyle-5.0.catalog
Patch0:         checkstyle-5.0-build.patch
Patch1:         checkstyle-5.0-javadoc-crosslink.patch
Patch2:         checkstyle-5.0-google-collections.patch
Requires(post): jpackage-utils >= 0:1.7.2
Requires(postun): jpackage-utils >= 0:1.7.2
Requires:       ant >= 0:1.6
Requires:       antlr >= 0:2.7.1
Requires:       google-collections
Requires:       jakarta-commons-logging
Requires:       jakarta-commons-cli
Requires:       jakarta-commons-beanutils
Requires:       jakarta-commons-collections
Requires:       jpackage-utils >= 0:1.7.2
Requires:       jaxp_parser_impl
BuildRequires:  ant >= 0:1.6
BuildRequires:  ant-javadoc
BuildRequires:  ant-nodeps >= 0:1.6
BuildRequires:  antlr >= 0:2.7.1
BuildRequires:  antlr-javadoc
BuildRequires:  google-collections
BuildRequires:  jakarta-commons-beanutils
BuildRequires:  jakarta-commons-beanutils-javadoc
BuildRequires:  jakarta-commons-cli
BuildRequires:  jakarta-commons-logging
BuildRequires:  java-devel
BuildRequires:  java-javadoc
BuildRequires:  jpackage-utils >= 0:1.7.2
BuildRequires:  junit4
BuildRequires:  velocity
BuildRequires:  xalan-j2
# xerces-j2 because tests fail with gnujaxp...
BuildRequires:  xerces-j2
BuildRequires:  xml-commons-jaxp-1.3-apis-javadoc
%if %with tests
BuildRequires:  ant-junit >= 0:1.6
BuildRequires:  emma
%endif
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
BuildArch:      noarch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
A tool for checking Java source code for adherence to a set of rules.

%package demo
Group:          Development/Build Tools
Summary:        Demos for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description demo
Demonstrations and samples for %{name}.

%package javadoc
Group:          Development/Documentation
Summary:        Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%package manual
Group:          Development/Build Tools
Summary:        Manual for %{name}

%description manual
Manual for %{name}.

%prep
%setup -q -n checkstyle-src-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%{_bindir}/find -name "*.jar" | %{_bindir}/xargs -t %{__rm}

%{__perl} -pi -e 's/\r$//g;' \
build.xml \
checkstyle_checks.xml \
java.header \
LICENSE.apache20 \
LICENSE \
README \
RIGHTS.antlr \
sun_checks.xml \
suppressions.xml \
src/xdocs/css/*.css \
src/xdocs/*.xml \
src/xdocs/stylesheets/*.vsl \
src/xdocs/stylesheets/*.xml

%build
export OPT_JAR_LIST=`%{__cat} %{_sysconfdir}/ant.d/{junit,nodeps}`
export CLASSPATH=$(build-classpath commons-collections commons-lang)

pushd lib
ln -sf $(build-classpath antlr) .
ln -sf $(build-classpath commons-beanutils-core) .
ln -sf $(build-classpath commons-cli) commons-cli-1.1.jar
ln -sf $(build-classpath commons-logging) .
%if %with tests
ln -sf $(build-classpath emma) .
ln -sf $(build-classpath emma_ant) .
%endif
ln -sf $(build-classpath google-collections) google-collect-snapshot-20090211.jar
ln -sf $(build-classpath jdom) jdom-b9.jar
ln -sf $(build-classpath junit4) junit-4.4.jar
ln -sf $(build-classpath velocity) velocity-dep-1.4.jar
popd

%{ant} \
  -Dbuild.sysclasspath=first \
  -Dant.javadoc=%{_javadocdir}/ant \
  -Dantlr.javadoc=%{_javadocdir}/antlr \
  -Djava.javadoc=%{_javadocdir}/java \
  -Djaxp.javadoc=%{_javadocdir}/xml-commons-apis \
  -Dbeanutils.javadoc=%{_javadocdir}/jakarta-commons-beanutils \
%if %with tests
  run.tests \
%endif
  build.bindist

%install
%{__rm} -rf %{buildroot}

# jars
%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -p target/dist/checkstyle-%{version}/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}.jar; do %{__ln_s} ${jar} `echo $jar| %__sed "s|-%{version}||g"`; done)

# poms
%add_to_maven_depmap checkstyle checkstyle %{version} JPP %{name}

%{__mkdir_p} %{buildroot}%{_datadir}/maven2/poms
%{__cp} -p pom.xml %{buildroot}%{_datadir}/maven2/poms/JPP.%{name}.pom

# script
%{__mkdir_p} %{buildroot}%{_bindir}
%{__install} -p -m 0755 %{SOURCE1} %{buildroot}%{_bindir}/%{name}

# dtds
%{__mkdir_p} %{buildroot}%{_datadir}/xml/%{name}
%{__cp} -p %{SOURCE2} %{buildroot}%{_datadir}/xml/%{name}/catalog
%{__cp} -p src/checkstyle/com/puppycrawl/tools/checkstyle/*.dtd %{buildroot}%{_datadir}/xml/%{name}
%{__mkdir_p} %{buildroot}%{_sysconfdir}/sgml
/bin/touch %{buildroot}%{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat

# javadoc
%{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__cp} -pr target/dist/checkstyle-%{version}/docs/api/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__ln_s} %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

# docs
# FIXME: (dwalluck): breaks --short-circuit
%{__rm} -rf target/dist/%{name}-%{version}/docs/api
%{__ln_s} %{_javadocdir}/%{name} target/dist/%{name}-%{version}/docs/api

# demo
%{__mkdir_p} %{buildroot}%{_datadir}/%{name}
%{__cp} -pr target/dist/%{name}-%{version}/contrib/* %{buildroot}%{_datadir}/%{name}

# ant.d
%{__mkdir_p} %{buildroot}%{_sysconfdir}/ant.d
%{__cat} > %{buildroot}%{_sysconfdir}/ant.d/%{name} << EOF
checkstyle antlr google-collections jakarta-commons-beanutils jakarta-commons-cli jakarta-commons-logging jakarta-commons-collections jaxp_parser_impl
EOF

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
%{__rm} -rf %{buildroot}

%post
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif
/bin/touch %{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat 2>/dev/null
# Note that we're using a fully versioned catalog, so this is always ok.
if [ -x %{_bindir}/install-catalog -a -d %{_sysconfdir}/sgml ]; then
  %{_bindir}/install-catalog --add \
    %{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat \
    %{_datadir}/xml/%{name}/catalog > /dev/null 2>&1 || :
fi

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif
# Note that we're using a fully versioned catalog, so this is always ok.
if [ -x %{_bindir}/install-catalog -a -d %{_sysconfdir}/sgml ]; then
  %{_bindir}/install-catalog --remove \
    %{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat \
    %{_datadir}/xml/%{name}/catalog > /dev/null 2>&1 || :
fi

%files
%defattr(0644,root,root,0755)
%doc LICENSE LICENSE.apache20 README RIGHTS.antlr
%doc build.xml checkstyle_checks.xml java.header sun_checks.xml suppressions.xml
%{_javadir}/%{name}.jar
%{_javadir}/%{name}-%{version}.jar
%{_datadir}/xml/%{name}
%attr(0755,root,root) %{_bindir}/%{name}
%config(noreplace) %{_sysconfdir}/ant.d/%{name}
%{_datadir}/maven2/poms/JPP.%{name}.pom
%{_mavendepmapfragdir}/%{name}
%ghost %{_sysconfdir}/sgml/%{name}-%{version}-%{release}.cat
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-%{version}.jar.*
%endif

%files demo
%defattr(0644,root,root,0755)
%{_datadir}/%{name}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%files manual
%defattr(0644,root,root,0755)
%doc target/dist/%{name}-%{version}/docs/*

%changelog
* Mon Apr 20 2009 David Walluck <dwalluck@redhat.com> 0:5.0-1
- 5.0

* Fri Dec 05 2008 David Walluck <dwalluck@redhat.com> 0:5.0-0.beta01.6
- own installed catalog file

* Wed Oct 08 2008 David Walluck <dwalluck@redhat.com> 0:5.0-0.beta01.5
- add google-collections to %%{_sysconfdir}/ant.d/%%{name}

* Fri Aug 08 2008 David Walluck <dwalluck@redhat.com> 0:5.0-0.beta01.4
- fix stylesheet eol

* Fri Aug 08 2008 David Walluck <dwalluck@redhat.com> 0:5.0-0.beta01.3
- really fix doc eol

* Fri Aug 08 2008 David Walluck <dwalluck@redhat.com> 0:5.0-0.beta01.2
- fix doc eol
- fix more than one changelog

* Thu Aug 07 2008 David Walluck <dwalluck@redhat.com> 0:5.0-0.beta01.1
- 5.0-beta01
- optional package does not exist any longer
- disable tests by default (emma fails)

* Wed Jul 04 2007 Ralph Apel <r.apel@r-apel.de> 0:4.3-1jpp
- Upgrade to 4.3
- Make Vendor, Distribution based on macro
- Add gcj_support option

* Thu Mar 30 2006 Ralph Apel <r.apel@r-apel.de> 0:4.1-3jpp
- replace avalon-logkit by excalibur-avalon-logkit as BR

* Wed Feb 22 2006 Ralph Apel <r.apel@r-apel.de> 0:4.1-2jpp
- add exclude to javadoc task iot build with java-1.4.2-bea

* Wed Feb 15 2006 Ralph Apel <r.apel@r-apel.de> 0:4.1-1jpp
- update to 4.1 for JPP-1.7
- reduce dependencies

* Wed Feb 15 2006 Ralph Apel <r.apel@r-apel.de> 0:3.5-2jpp
- set locale iot avoid failure of GeneratedJava14LexerTest

* Mon Feb 21 2005 David Walluck <david@jpackage.org> 0:3.5-1jpp
- 0.3.5
- fix ant task with new ant
- add more files to %%doc

* Fri Aug 20 2004 Ralph Apel <r.apel at r-apel.de> - 0:3.4-4jpp
- Build with ant-1.6.2
- Runtime Req ant >= 0:1.6.2

* Fri Aug 06 2004 Ralph Apel <r.apel at r-apel.de> - 0:3.4-3jpp
- Void change

* Tue Jun 01 2004 Randy Watler <rwatler at finali.com> - 0:3.4-2jpp
- Upgrade to Ant 1.6.X

* Mon Apr 12 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:3.4-1jpp
- Update to 3.4.
- Make -optional depend on the main package.
- Update DTD catalog, move DTDs to %%{_datadir}/xml/%%{name}.
- New style versionless javadoc dir symlinking.
- Add -optional jar to classpath in startup script if available.

* Tue Jan 20 2004 David Walluck <david@anti-microsoft.org> 0:3.3-1jpp
- 3.3
- rediff patches
- add `optional' subpackage

* Fri Jul 11 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:3.1-2jpp
- Install DTDs into %%{_datadir}/sgml/%%{name}.
- Include catalog for DTDs, and install it if %%{_bindir}/install-catalog
  is available.
- Javadoc crosslinking.

* Wed Jun  4 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:3.1-1jpp
- Update to 3.1.
- Non-versioned javadoc symlinking.

* Fri Apr  4 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:3.0-2jpp
- Rebuild for JPackage 1.5.

* Sat Mar  1 2003 Ville Skyttä <ville.skytta at iki.fi> - 3.0-1jpp
- Update to 3.0.
- Run unit tests during build.
- Separate manual package.

* Sat Sep 14 2002 Ville Skyttä <ville.skytta at iki.fi> 2.4-1jpp
- 2.4.
- No RPM macros in source URL.
- Use (patched) ant build.bindist task to fix docs.

* Thu Jul 11 2002 Ville Skyttä <ville.skytta at iki.fi> 2.3-2jpp
- Unbreak build.
- Add shell script.

* Tue Jul  9 2002 Ville Skyttä <ville.skytta at iki.fi> 2.3-1jpp
- Updated to 2.3.
- Use sed instead of bash 2 extension when symlinking jars during build.
- BuildRequires ant-optional.

* Fri May 10 2002 Ville Skyttä <ville.skytta at iki.fi> 2.2-1jpp
- Updated to 2.2.
- Added versioned requirements.
- Fixed Distribution and Group tags.
- Added demo package.

* Sun Mar 03 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 2.1-1jpp
- first jpp release
